Any class

Any contains an arbitrary serialized message along with a URL that describes the type of the serialized message.

Inheritance

Constructors

Any({required Map<String, dynamic> json})
Any.from(ProtoMessage message)
Create an Any from an existing message.
Any.fromJson(Object? json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
json → Map<String, dynamic>
The raw JSON encoding of the underlying value.
final
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
typeName → String
Return the fully qualified name of the contained type.
no setter

Methods

isType(String name) → bool
Returns whether the type represented by this Any is the same as name.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
packInto(ProtoMessage message) → void
Serialize the given message into this Any instance.
toJson() → Map<String, dynamic>
override
toString() → String
A string representation of this object.
override
unpackFrom<T extends ProtoMessage, S>(T decoder(S)) → T
Deserialize a message from this Any object.

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String