BoolValue class final
Wrapper message for bool.
The JSON representation for BoolValue is JSON true and false.
Not recommended for use in new APIs, but still useful for legacy APIs and has no plan to be removed.
- Inheritance
-
- Object
- ProtoMessage
- BoolValue
Constructors
- BoolValue({bool value = false})
- BoolValue.fromJson(Object? json)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- qualifiedName → String
-
The fully qualified name of this message, i.e.,
google.protobuf.Durationorgoogle.rpc.ErrorInfo.finalinherited - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → bool
-
The bool value.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object -
override
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fullyQualifiedName → const String