Enum class final

Enum type definition.

New usages of this message as an alternative to EnumDescriptorProto are strongly discouraged. This message does not reliability preserve all information necessary to model the schema and preserve semantics. Instead make use of FileDescriptorSet which preserves the necessary information.

Inheritance

Constructors

Enum({String name = '', List<EnumValue> enumvalue = const [], List<Option> options = const [], SourceContext? sourceContext, Syntax syntax = Syntax.$default, String edition = ''})
Enum.fromJson(Object? j)
factory

Properties

edition String
The source edition string, only valid when syntax is SYNTAX_EDITIONS.
final
enumvalue List<EnumValue>
Enum value definitions.
final
hashCode int
The hash code for this object.
no setterinherited
name String
Enum type name.
final
options List<Option>
Protocol buffer options.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sourceContext SourceContext?
The source context.
final
syntax Syntax
The source syntax.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
override
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String