EnumValue class final

Enum value definition.

New usages of this message as an alternative to EnumValueDescriptorProto are strongly discouraged. This message does not reliability preserve all information necessary to model the schema and preserve semantics. Instead make use of FileDescriptorSet which preserves the necessary information.

Inheritance

Constructors

EnumValue({String name = '', int number = 0, List<Option> options = const []})
EnumValue.fromJson(Object? j)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
name String
Enum value name.
final
number int
Enum value number.
final
options List<Option>
Protocol buffer options.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
override
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String