Method class final

Method represents a method of an API interface.

New usages of this message as an alternative to MethodDescriptorProto are strongly discouraged. This message does not reliability preserve all information necessary to model the schema and preserve semantics. Instead make use of FileDescriptorSet which preserves the necessary information.

Inheritance

Constructors

Method({String name = '', String requestTypeUrl = '', bool requestStreaming = false, String responseTypeUrl = '', bool responseStreaming = false, List<Option> options = const [], Syntax syntax = Syntax.$default, String edition = ''})
Method.fromJson(Object? j)
factory

Properties

edition String
The source edition string, only valid when syntax is SYNTAX_EDITIONS.
final
hashCode int
The hash code for this object.
no setterinherited
name String
The simple name of this method.
final
options List<Option>
Any metadata attached to the method.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
requestStreaming bool
If true, the request is streamed.
final
requestTypeUrl String
A URL of the input message type.
final
responseStreaming bool
If true, the response is streamed.
final
responseTypeUrl String
The URL of the output message type.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
syntax Syntax
The source syntax of this method.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
override
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String