edition property

String edition
final

The source edition string, only valid when syntax is SYNTAX_EDITIONS.

This field should be ignored, instead the edition should be inherited from Api. This is similar to Field and EnumValue.

Implementation

final String edition;