syntax property
The source syntax of this method.
This field should be ignored, instead the syntax should be inherited from Api. This is similar to Field and EnumValue.
Implementation
final Syntax syntax;
The source syntax of this method.
This field should be ignored, instead the syntax should be inherited from Api. This is similar to Field and EnumValue.
final Syntax syntax;