Syntax class final

The syntax in which a protocol buffer element is defined.

Inheritance

Constructors

Syntax(String value)
const
Syntax.fromJson(Object? json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
isNotDefault → bool
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → String
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object?
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

$default → const Syntax
The default value for Syntax.
syntaxEditions → const Syntax
Syntax editions.
syntaxProto2 → const Syntax
Syntax proto2.
syntaxProto3 → const Syntax
Syntax proto3.