Type class final
A protocol buffer message type.
New usages of this message as an alternative to DescriptorProto are strongly discouraged. This message does not reliability preserve all information necessary to model the schema and preserve semantics. Instead make use of FileDescriptorSet which preserves the necessary information.
- Inheritance
-
- Object
- ProtoMessage
- Type
Constructors
Properties
- edition → String
-
The source edition string, only valid when syntax is SYNTAX_EDITIONS.
final
-
fields
→ List<
Field> -
The list of fields.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
The fully qualified message name.
final
-
oneofs
→ List<
String> -
The list of types appearing in
oneofdefinitions in this type.final -
options
→ List<
Option> -
The protocol buffer options.
final
- qualifiedName → String
-
The fully qualified name of this message, i.e.,
google.protobuf.Durationorgoogle.rpc.ErrorInfo.finalinherited - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sourceContext → SourceContext?
-
The source context.
final
- syntax → Syntax
-
The source syntax.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object -
override
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fullyQualifiedName → const String