Value class

Value represents a dynamically typed value which can be either null, a number, a string, a boolean, a recursive struct value, or a list of values. A producer of value is expected to set one of these variants. Absence of any variant indicates an error.

The JSON representation for Value is JSON value.

Inheritance

Constructors

Value({NullValue? nullValue, double? numberValue, String? stringValue, bool? boolValue, Struct? structValue, ListValue? listValue})
Value.fromJson(Object? json)
factory

Properties

boolValue → bool?
Represents a boolean value.
final
hashCode → int
The hash code for this object.
no setterinherited
listValue → ListValue?
Represents a repeated Value.
final
nullValue → NullValue?
Represents a null value.
final
numberValue → double?
Represents a double value.
final
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stringValue → String?
Represents a string value.
final
structValue → Struct?
Represents a structured value.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object?
override
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String